summaryrefslogtreecommitdiff
path: root/protocols/Twitter/src/proto.cpp
diff options
context:
space:
mode:
authordartraiden <wowemuh@gmail.com>2019-07-21 19:59:18 +0300
committerdartraiden <wowemuh@gmail.com>2019-07-21 19:59:18 +0300
commitb078dfb78c89aea87cd422eae52694738e473cf3 (patch)
treeca896e82a8a5ce81f80d041f4aee7fdeeb007162 /protocols/Twitter/src/proto.cpp
parentee7e29d02e94e969c1154515cd0c408c591a2414 (diff)
Restore "Free for chat" status support (fixes #1963)
Diffstat (limited to 'protocols/Twitter/src/proto.cpp')
-rw-r--r--protocols/Twitter/src/proto.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/protocols/Twitter/src/proto.cpp b/protocols/Twitter/src/proto.cpp
index 0496409e9b..e7d1e8806f 100644
--- a/protocols/Twitter/src/proto.cpp
+++ b/protocols/Twitter/src/proto.cpp
@@ -169,8 +169,8 @@ int TwitterProto::SetStatus(int new_status)
return 0;
m_iDesiredStatus = new_status;
- // 40072 - 40077 are the "online" statuses, basically every status except offline. see statusmodes.h
- if (new_status >= 40072 && new_status <= 40077) {
+ // 40072 - 40078 are the "online" statuses, basically every status except offline. see statusmodes.h
+ if (new_status >= 40072 && new_status <= 40078) {
m_iDesiredStatus = ID_STATUS_ONLINE; //i think i have to set this so it forces the twitter proto to be online (and not away, DND, etc)
@@ -179,7 +179,7 @@ int TwitterProto::SetStatus(int new_status)
return 0;
// if we're already connected, and we change to another connected status, don't try and reconnect!
- if (old_status >= 40072 && old_status <= 40077)
+ if (old_status >= 40072 && old_status <= 40078)
return 0;
// i think here we tell the proto interface struct that we're connecting, just so it knows